"""
Italica - A simple library for adding markdown-style formatting to print and input functions.

This library provides easy-to-use functions for formatting text in the terminal
with markdown-style syntax like **bold**, *italic*, and more.

Author: 7vntii
GitHub: https://github.com/7vntii
PyPI: https://pypi.org/user/7vntii
"""

__version__ = "1.0.0"
__author__ = "7vntii"
__email__ = "jj9dptr57@mozmail.com"
__url__ = "https://github.com/7vntii/italica"

from .core import print_fmt, input_fmt, format_text
from .formatters import (
    bold, italic, underline, strikethrough, 
    red, green, blue, yellow, magenta, cyan,
    bright_red, bright_green, bright_blue, bright_yellow, bright_magenta, bright_cyan
)

__all__ = [
    # Main functions
    'print_fmt', 'input_fmt', 'format_text',
    
    # Text formatting
    'bold', 'italic', 'underline', 'strikethrough',
    
    # Colors
    'red', 'green', 'blue', 'yellow', 'magenta', 'cyan',
    'bright_red', 'bright_green', 'bright_blue', 'bright_yellow', 'bright_magenta', 'bright_cyan',
    
    # Version info
    '__version__', '__author__', '__email__', '__url__'
]



"""
Text formatting utilities for the italica library.

This module provides ANSI escape codes and formatting functions for text styling
and colors that work across different platforms.
"""

import sys

# ANSI escape codes for text formatting
FORMATTERS = {
    'bold': '\033[1m',
    'italic': '\033[3m',
    'underline': '\033[4m',
    'strikethrough': '\033[9m',
    'code': '\033[7m',  # Reverse video (monospace effect)
}

# ANSI escape codes for colors
ANSI_CODES = {
    # Reset
    'reset': '\033[0m',
    
    # Regular colors
    'red': '\033[31m',
    'green': '\033[32m',
    'blue': '\033[34m',
    'yellow': '\033[33m',
    'magenta': '\033[35m',
    'cyan': '\033[36m',
    'white': '\033[37m',
    'black': '\033[30m',
    
    # Bright colors
    'bright_red': '\033[91m',
    'bright_green': '\033[92m',
    'bright_blue': '\033[94m',
    'bright_yellow': '\033[93m',
    'bright_magenta': '\033[95m',
    'bright_cyan': '\033[96m',
    'bright_white': '\033[97m',
    'bright_black': '\033[90m',
    
    # Background colors
    'bg_red': '\033[41m',
    'bg_green': '\033[42m',
    'bg_blue': '\033[44m',
    'bg_yellow': '\033[43m',
    'bg_magenta': '\033[45m',
    'bg_cyan': '\033[46m',
    'bg_white': '\033[47m',
    'bg_black': '\033[40m',
    
    # Bright background colors
    'bg_bright_red': '\033[101m',
    'bg_bright_green': '\033[102m',
    'bg_bright_blue': '\033[104m',
    'bg_bright_yellow': '\033[103m',
    'bg_bright_magenta': '\033[105m',
    'bg_bright_cyan': '\033[106m',
    'bg_bright_white': '\033[107m',
    'bg_bright_black': '\033[100m',
}

# Initialize colorama for Windows compatibility
def _init_windows_colors():
    """Initialize colorama for Windows color support."""
    if sys.platform.startswith('win'):
        try:
            import colorama
            colorama.init()
        except ImportError:
            # colorama not available, colors will be disabled on Windows
            pass

# Initialize colors on module import
_init_windows_colors()


# Convenience functions for text formatting
def bold(text: str) -> str:
    """Make text bold."""
    return f"{FORMATTERS['bold']}{text}{ANSI_CODES['reset']}"


def italic(text: str) -> str:
    """Make text italic."""
    return f"{FORMATTERS['italic']}{text}{ANSI_CODES['reset']}"


def underline(text: str) -> str:
    """Underline text."""
    return f"{FORMATTERS['underline']}{text}{ANSI_CODES['reset']}"


def strikethrough(text: str) -> str:
    """Strikethrough text."""
    return f"{FORMATTERS['strikethrough']}{text}{ANSI_CODES['reset']}"


def code(text: str) -> str:
    """Format text as code (monospace)."""
    return f"{FORMATTERS['code']}{text}{ANSI_CODES['reset']}"


# Color functions
def red(text: str) -> str:
    """Color text red."""
    return f"{ANSI_CODES['red']}{text}{ANSI_CODES['reset']}"


def green(text: str) -> str:
    """Color text green."""
    return f"{ANSI_CODES['green']}{text}{ANSI_CODES['reset']}"


def blue(text: str) -> str:
    """Color text blue."""
    return f"{ANSI_CODES['blue']}{text}{ANSI_CODES['reset']}"


def yellow(text: str) -> str:
    """Color text yellow."""
    return f"{ANSI_CODES['yellow']}{text}{ANSI_CODES['reset']}"


def magenta(text: str) -> str:
    """Color text magenta."""
    return f"{ANSI_CODES['magenta']}{text}{ANSI_CODES['reset']}"


def cyan(text: str) -> str:
    """Color text cyan."""
    return f"{ANSI_CODES['cyan']}{text}{ANSI_CODES['reset']}"


def white(text: str) -> str:
    """Color text white."""
    return f"{ANSI_CODES['white']}{text}{ANSI_CODES['reset']}"


def black(text: str) -> str:
    """Color text black."""
    return f"{ANSI_CODES['black']}{text}{ANSI_CODES['reset']}"


# Bright color functions
def bright_red(text: str) -> str:
    """Color text bright red."""
    return f"{ANSI_CODES['bright_red']}{text}{ANSI_CODES['reset']}"


def bright_green(text: str) -> str:
    """Color text bright green."""
    return f"{ANSI_CODES['bright_green']}{text}{ANSI_CODES['reset']}"


def bright_blue(text: str) -> str:
    """Color text bright blue."""
    return f"{ANSI_CODES['bright_blue']}{text}{ANSI_CODES['reset']}"


def bright_yellow(text: str) -> str:
    """Color text bright yellow."""
    return f"{ANSI_CODES['bright_yellow']}{text}{ANSI_CODES['reset']}"


def bright_magenta(text: str) -> str:
    """Color text bright magenta."""
    return f"{ANSI_CODES['bright_magenta']}{text}{ANSI_CODES['reset']}"


def bright_cyan(text: str) -> str:
    """Color text bright cyan."""
    return f"{ANSI_CODES['bright_cyan']}{text}{ANSI_CODES['reset']}"


def bright_white(text: str) -> str:
    """Color text bright white."""
    return f"{ANSI_CODES['bright_white']}{text}{ANSI_CODES['reset']}"


def bright_black(text: str) -> str:
    """Color text bright black (gray)."""
    return f"{ANSI_CODES['bright_black']}{text}{ANSI_CODES['reset']}"


# Background color functions
def bg_red(text: str) -> str:
    """Set background color to red."""
    return f"{ANSI_CODES['bg_red']}{text}{ANSI_CODES['reset']}"


def bg_green(text: str) -> str:
    """Set background color to green."""
    return f"{ANSI_CODES['bg_green']}{text}{ANSI_CODES['reset']}"


def bg_blue(text: str) -> str:
    """Set background color to blue."""
    return f"{ANSI_CODES['bg_blue']}{text}{ANSI_CODES['reset']}"


def bg_yellow(text: str) -> str:
    """Set background color to yellow."""
    return f"{ANSI_CODES['bg_yellow']}{text}{ANSI_CODES['reset']}"


def bg_magenta(text: str) -> str:
    """Set background color to magenta."""
    return f"{ANSI_CODES['bg_magenta']}{text}{ANSI_CODES['reset']}"


def bg_cyan(text: str) -> str:
    """Set background color to cyan."""
    return f"{ANSI_CODES['bg_cyan']}{text}{ANSI_CODES['reset']}"


def bg_white(text: str) -> str:
    """Set background color to white."""
    return f"{ANSI_CODES['bg_white']}{text}{ANSI_CODES['reset']}"


def bg_black(text: str) -> str:
    """Set background color to black."""
    return f"{ANSI_CODES['bg_black']}{text}{ANSI_CODES['reset']}"


# Utility function to strip ANSI codes
def strip_ansi(text: str) -> str:
    """
    Remove all ANSI escape codes from text.
    
    Args:
        text (str): Text that may contain ANSI escape codes
        
    Returns:
        str: Text with all ANSI escape codes removed
        
    Examples:
        >>> strip_ansi(bold("Hello"))
        'Hello'
        
        >>> strip_ansi(red("Error"))
        'Error'
    """
    import re
    # Remove ANSI escape codes
    ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
    return ansi_escape.sub('', text)


# Utility function to check if text contains ANSI codes
def has_ansi(text: str) -> bool:
    """
    Check if text contains ANSI escape codes.
    
    Args:
        text (str): Text to check
        
    Returns:
        bool: True if text contains ANSI escape codes, False otherwise
    """
    import re
    ansi_escape = re.compile(r'\x1B(?:[@-Z\\-_]|\[[0-?]*[ -/]*[@-~])')
    return bool(ansi_escape.search(text))



"""
Core functionality for the italica library.

This module provides the main functions for formatting text with markdown-style syntax
and handling print and input operations with formatting.
"""

import sys
import re
from typing import Optional, Any
from .formatters import FORMATTERS, ANSI_CODES


def format_text(text: str, enable_colors: bool = True) -> str:
    """
    Format text with markdown-style syntax.
    
    Supported formats:
    - **text** or __text__ -> bold
    - *text* or _text_ -> italic
    - ~~text~~ -> strikethrough
    - `text` -> code (monospace)
    - [color]text[/color] -> colored text (where color is red, green, blue, etc.)
    
    Args:
        text (str): The text to format
        enable_colors (bool): Whether to enable color formatting (default: True)
        
    Returns:
        str: The formatted text with ANSI escape codes
        
    Examples:
        >>> format_text("Hello **world**!")
        'Hello \x1b[1mworld\x1b[0m!'
        
        >>> format_text("This is *italic* and **bold**")
        'This is \x1b[3mitalic\x1b[0m and \x1b[1mbold\x1b[0m'
    """
    if not text:
        return text
    
    # Define markdown patterns
    patterns = [
        # Bold: **text** or __text__
        (r'\*\*(.*?)\*\*', 'bold'),
        (r'__(.*?)__', 'bold'),
        
        # Italic: *text* or _text_
        (r'\*(.*?)\*', 'italic'),
        (r'_(.*?)_', 'italic'),
        
        # Strikethrough: ~~text~~
        (r'~~(.*?)~~', 'strikethrough'),
        
        # Code: `text`
        (r'`(.*?)`', 'code'),
        
        # Colors: [color]text[/color]
        (r'\[(red|green|blue|yellow|magenta|cyan|bright_red|bright_green|bright_blue|bright_yellow|bright_magenta|bright_cyan)\](.*?)\[/\1\]', 'color'),
    ]
    
    formatted_text = text
    
    for pattern, format_type in patterns:
        if format_type == 'color':
            # Handle color formatting
            def color_replace(match):
                color_name = match.group(1)
                content = match.group(2)
                if enable_colors and color_name in ANSI_CODES:
                    return f"{ANSI_CODES[color_name]}{content}{ANSI_CODES['reset']}"
                return content
            
            formatted_text = re.sub(pattern, color_replace, formatted_text)
        else:
            # Handle other formatting
            def format_replace(match):
                content = match.group(1)
                if enable_colors and format_type in FORMATTERS:
                    return f"{FORMATTERS[format_type]}{content}{ANSI_CODES['reset']}"
                return content
            
            formatted_text = re.sub(pattern, format_replace, formatted_text)
    
    return formatted_text


def print_fmt(*args, sep: str = " ", end: str = "\n", file=None, flush: bool = False, 
              enable_colors: bool = None) -> None:
    """
    Print formatted text with markdown-style syntax.
    
    This function works like the built-in print() function but supports markdown formatting.
    
    Args:
        *args: Objects to print
        sep (str): Separator between objects (default: " ")
        end (str): String appended after the last value (default: "\n")
        file: A file-like object to write to (default: sys.stdout)
        flush (bool): Whether to forcibly flush the stream (default: False)
        enable_colors (bool): Whether to enable color formatting. If None, auto-detects terminal support
        
    Examples:
        >>> print_fmt("Hello **world**!")
        Hello world! (with bold formatting)
        
        >>> print_fmt("This is *italic* and **bold**")
        This is italic and bold (with formatting)
        
        >>> print_fmt("[red]Error message[/red]")
        Error message (in red)
    """
    if enable_colors is None:
        enable_colors = _supports_color(file or sys.stdout)
    
    # Format each argument
    formatted_args = []
    for arg in args:
        if isinstance(arg, str):
            formatted_args.append(format_text(arg, enable_colors))
        else:
            formatted_args.append(str(arg))
    
    # Join and print
    text = sep.join(formatted_args)
    print(text, end=end, file=file, flush=flush)


def input_fmt(prompt: str = "", enable_colors: bool = None) -> str:
    """
    Get user input with formatted prompt.
    
    This function works like the built-in input() function but supports markdown formatting in the prompt.
    
    Args:
        prompt (str): The prompt to display (supports markdown formatting)
        enable_colors (bool): Whether to enable color formatting. If None, auto-detects terminal support
        
    Returns:
        str: The user's input
        
    Examples:
        >>> name = input_fmt("Enter your **name**: ")
        Enter your name: (with bold formatting)
        
        >>> age = input_fmt("[green]How old are you?[/green] ")
        How old are you? (in green)
    """
    if enable_colors is None:
        enable_colors = _supports_color(sys.stdout)
    
    formatted_prompt = format_text(prompt, enable_colors)
    return input(formatted_prompt)


def _supports_color(stream) -> bool:
    """
    Check if the given stream supports color output.
    
    Args:
        stream: The stream to check
        
    Returns:
        bool: True if the stream supports colors, False otherwise
    """
    # Check if we're on Windows
    if sys.platform.startswith('win'):
        # On Windows, check if we're in a terminal that supports colors
        try:
            import colorama
            return True
        except ImportError:
            # Without colorama, Windows console doesn't support ANSI colors well
            return False
    
    # On Unix-like systems, check if we're in a terminal
    if hasattr(stream, 'isatty') and stream.isatty():
        return True
    
    return False


# Convenience functions for common use cases
def print_bold(text: str, **kwargs) -> None:
    """Print text in bold."""
    print_fmt(f"**{text}**", **kwargs)


def print_italic(text: str, **kwargs) -> None:
    """Print text in italic."""
    print_fmt(f"*{text}*", **kwargs)


def print_error(text: str, **kwargs) -> None:
    """Print text in red (for error messages)."""
    print_fmt(f"[red]{text}[/red]", **kwargs)


def print_success(text: str, **kwargs) -> None:
    """Print text in green (for success messages)."""
    print_fmt(f"[green]{text}[/green]", **kwargs)


def print_warning(text: str, **kwargs) -> None:
    """Print text in yellow (for warning messages)."""
    print_fmt(f"[yellow]{text}[/yellow]", **kwargs)



"""
Tests for the core functionality of the italica library.
"""

import sys
import io
import pytest
from italica.core import format_text, print_fmt, input_fmt, _supports_color
from italica.formatters import strip_ansi, has_ansi


class TestFormatText:
    """Test the format_text function."""
    
    def test_bold_formatting(self):
        """Test bold text formatting."""
        result = format_text("Hello **world**!")
        assert "**world**" not in result
        assert has_ansi(result)
    
    def test_italic_formatting(self):
        """Test italic text formatting."""
        result = format_text("This is *italic* text")
        assert "*italic*" not in result
        assert has_ansi(result)
    
    def test_strikethrough_formatting(self):
        """Test strikethrough text formatting."""
        result = format_text("This is ~~crossed out~~ text")
        assert "~~crossed out~~" not in result
        assert has_ansi(result)
    
    def test_code_formatting(self):
        """Test code text formatting."""
        result = format_text("This is `code` text")
        assert "`code`" not in result
        assert has_ansi(result)
    
    def test_color_formatting(self):
        """Test color text formatting."""
        result = format_text("[red]Red text[/red]")
        assert "[red]Red text[/red]" not in result
        assert has_ansi(result)
    
    def test_bright_color_formatting(self):
        """Test bright color text formatting."""
        result = format_text("[bright_red]Bright red text[/bright_red]")
        assert "[bright_red]Bright red text[/bright_red]" not in result
        assert has_ansi(result)
    
    def test_combined_formatting(self):
        """Test combined formatting."""
        result = format_text("This is **bold** and *italic* and ~~strikethrough~~")
        assert "**bold**" not in result
        assert "*italic*" not in result
        assert "~~strikethrough~~" not in result
        assert has_ansi(result)
    
    def test_no_formatting(self):
        """Test text with no formatting."""
        text = "Plain text without formatting"
        result = format_text(text)
        assert result == text
        assert not has_ansi(result)
    
    def test_empty_string(self):
        """Test empty string formatting."""
        result = format_text("")
        assert result == ""
    
    def test_none_string(self):
        """Test None string formatting."""
        result = format_text(None)
        assert result == ""
    
    def test_disable_colors(self):
        """Test formatting with colors disabled."""
        result = format_text("**bold** [red]red[/red]", enable_colors=False)
        assert result == "**bold** [red]red[/red]"
        assert not has_ansi(result)


class TestPrintFmt:
    """Test the print_fmt function."""
    
    def test_basic_print(self, capsys):
        """Test basic print functionality."""
        print_fmt("Hello world")
        captured = capsys.readouterr()
        assert "Hello world" in captured.out
    
    def test_formatted_print(self, capsys):
        """Test formatted print functionality."""
        print_fmt("Hello **world**!")
        captured = capsys.readouterr()
        assert "Hello" in captured.out
        assert "world" in captured.out
        assert "**world**" not in captured.out
    
    def test_multiple_args(self, capsys):
        """Test print with multiple arguments."""
        print_fmt("Hello", "**world**", "!")
        captured = capsys.readouterr()
        assert "Hello" in captured.out
        assert "world" in captured.out
        assert "!" in captured.out
    
    def test_custom_sep(self, capsys):
        """Test print with custom separator."""
        print_fmt("Hello", "world", sep="|")
        captured = capsys.readouterr()
        assert "Hello|world" in captured.out
    
    def test_custom_end(self, capsys):
        """Test print with custom end."""
        print_fmt("Hello", end="!")
        captured = capsys.readouterr()
        assert captured.out == "Hello!"
    
    def test_disable_colors(self, capsys):
        """Test print with colors disabled."""
        print_fmt("**bold** [red]red[/red]", enable_colors=False)
        captured = capsys.readouterr()
        assert "**bold** [red]red[/red]" in captured.out
    
    def test_file_output(self):
        """Test print to file."""
        output = io.StringIO()
        print_fmt("Hello world", file=output)
        assert "Hello world" in output.getvalue()


class TestInputFmt:
    """Test the input_fmt function."""
    
    def test_basic_input(self, monkeypatch):
        """Test basic input functionality."""
        monkeypatch.setattr('builtins.input', lambda x: "test")
        result = input_fmt("Enter name: ")
        assert result == "test"
    
    def test_formatted_input(self, monkeypatch):
        """Test formatted input functionality."""
        monkeypatch.setattr('builtins.input', lambda x: "test")
        result = input_fmt("Enter your **name**: ")
        assert result == "test"
    
    def test_colored_input(self, monkeypatch):
        """Test colored input functionality."""
        monkeypatch.setattr('builtins.input', lambda x: "test")
        result = input_fmt("[green]Enter name:[/green] ")
        assert result == "test"
    
    def test_disable_colors(self, monkeypatch):
        """Test input with colors disabled."""
        monkeypatch.setattr('builtins.input', lambda x: "test")
        result = input_fmt("**bold** [red]red[/red]", enable_colors=False)
        assert result == "test"


class TestSupportsColor:
    """Test the _supports_color function."""
    
    def test_windows_platform(self, monkeypatch):
        """Test color support detection on Windows."""
        monkeypatch.setattr(sys, 'platform', 'win32')
        
        # Test with colorama available
        try:
            import colorama
            assert _supports_color(sys.stdout) == True
        except ImportError:
            # Without colorama, should return False on Windows
            assert _supports_color(sys.stdout) == False
    
    def test_unix_platform(self, monkeypatch):
        """Test color support detection on Unix."""
        monkeypatch.setattr(sys, 'platform', 'linux')
        
        # Mock isatty to return True
        class MockStream:
            def isatty(self):
                return True
        
        assert _supports_color(MockStream()) == True
    
    def test_non_terminal_stream(self, monkeypatch):
        """Test color support detection for non-terminal streams."""
        monkeypatch.setattr(sys, 'platform', 'linux')
        
        # Mock isatty to return False
        class MockStream:
            def isatty(self):
                return False
        
        assert _supports_color(MockStream()) == False


class TestStripAnsi:
    """Test the strip_ansi function."""
    
    def test_strip_ansi_codes(self):
        """Test stripping ANSI escape codes."""
        from italica.formatters import bold, red
        
        bold_text = bold("Hello")
        red_text = red("World")
        
        assert strip_ansi(bold_text) == "Hello"
        assert strip_ansi(red_text) == "World"
    
    def test_no_ansi_codes(self):
        """Test stripping from text without ANSI codes."""
        text = "Plain text"
        assert strip_ansi(text) == text
    
    def test_empty_string(self):
        """Test stripping from empty string."""
        assert strip_ansi("") == ""


class TestHasAnsi:
    """Test the has_ansi function."""
    
    def test_has_ansi_codes(self):
        """Test detection of ANSI codes."""
        from italica.formatters import bold, red
        
        bold_text = bold("Hello")
        red_text = red("World")
        
        assert has_ansi(bold_text) == True
        assert has_ansi(red_text) == True
    
    def test_no_ansi_codes(self):
        """Test detection of text without ANSI codes."""
        text = "Plain text"
        assert has_ansi(text) == False
    
    def test_empty_string(self):
        """Test detection in empty string."""
        assert has_ansi("") == False


class TestConvenienceFunctions:
    """Test convenience functions."""
    
    def test_print_bold(self, capsys):
        """Test print_bold function."""
        from italica.core import print_bold
        print_bold("Hello")
        captured = capsys.readouterr()
        assert "Hello" in captured.out
        assert has_ansi(captured.out)
    
    def test_print_italic(self, capsys):
        """Test print_italic function."""
        from italica.core import print_italic
        print_italic("Hello")
        captured = capsys.readouterr()
        assert "Hello" in captured.out
        assert has_ansi(captured.out)
    
    def test_print_error(self, capsys):
        """Test print_error function."""
        from italica.core import print_error
        print_error("Error message")
        captured = capsys.readouterr()
        assert "Error message" in captured.out
        assert has_ansi(captured.out)
    
    def test_print_success(self, capsys):
        """Test print_success function."""
        from italica.core import print_success
        print_success("Success message")
        captured = capsys.readouterr()
        assert "Success message" in captured.out
        assert has_ansi(captured.out)
    
    def test_print_warning(self, capsys):
        """Test print_warning function."""
        from italica.core import print_warning
        print_warning("Warning message")
        captured = capsys.readouterr()
        assert "Warning message" in captured.out
        assert has_ansi(captured.out)


if __name__ == "__main__":
    pytest.main([__file__])



from setuptools import setup, find_packages
import os

# Read the README file
def read_readme():
    with open("README.md", "r", encoding="utf-8") as fh:
        return fh.read()

# Read requirements
def read_requirements():
    with open("requirements.txt", "r", encoding="utf-8") as fh:
        return [line.strip() for line in fh if line.strip() and not line.startswith("#")]

setup(
    name="italica",
    version="1.0.0",
    author="7vntii",
    author_email="jj9dptr57@mozmail.com",
    description="A simple library for adding markdown-style formatting to print and input functions",
    long_description=read_readme(),
    long_description_content_type="text/markdown",
    url="https://github.com/7vntii/italica",
    project_urls={
        "Bug Reports": "https://github.com/7vntii/italica/issues",
        "Source": "https://github.com/7vntii/italica",
        "Documentation": "https://github.com/7vntii/italica#readme",
    },
    packages=find_packages(),
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Topic :: Text Processing :: Markup",
    ],
    python_requires=">=3.7",
    install_requires=read_requirements(),
    keywords="markdown, formatting, print, input, italic, bold, terminal, console",
    include_package_data=True,
    zip_safe=False,
)
